( cd usr/X11R6/lib/X11/fvwm95 ; rm -rf .fvwm95rc )
( cd usr/X11R6/lib/X11/fvwm95 ; ln -sf /usr/X11R6/lib/X11/fvwm95/system.fvwm95rc .fvwm95rc )
( cd usr/X11R6/lib/X11/fvwm95 ; rm -rf system.fvwm95rc )
( cd usr/X11R6/lib/X11/fvwm95 ; ln -sf ../../../../../etc/X11/fvwm95/system.fvwm95rc system.fvwm95rc )
